==> zhongyan-activity-service-api-1.0.23-linzhou-20220315.092435-4-sources.jar: cn/com/duiba/zhongyan/activity/service/api/enums/ErrorCodeEnum.java <==
package cn.com.duiba.zhongyan.activity.service.api.enums;

/**
 * @author LuHui
 * @description
 * @date 2021/11/25  16:30
 */
public enum ErrorCodeEnum implements BizError {

    FREQUENT_OPERATION(000001,"请求太频繁啦,请稍后再试"),

    PARAM_ERROR(100100, "参数错误"),
    ACTIVITY_NOT_EXIT(100101, "该活动不存在"),
    ACTIVITY_NOT_START(100102, "活动尚未开始"),
    ACTIVITY_ALREADY_END(100103, "活动已结束"),
    ANSWER_VERITY_AREA(100104, "仅限部门地区可参与"),
    ANSWER_VERIFY_USER(100105, "该活动仅限零售户参与"),
    ANSWER_VERITY(100106, "请先完成当前题目"),
    ANSWER_RECORD_NOT_EXIT(100107, "答题记录不存在"),
    ANSWER_NOT_COMMIT(100108, ""),

    NOT_OPERATION(200100, "无法操作"),
    NOT_ACQUIRE_LOCK(200101, "获取锁失败"),
    CAN_VIEW_ANSWER(200102,"查看答卷"),
    ANSWER_NOT_EMPTY(200103, "答案不能为空"),
    OPTION_NOT_EXIT(200104, "无此选项"),
    REQUIRED_MUST_FILL(200105,"该选项必填框必填"),
    ACTIVITY_END_VIEW_ANSWER(200106, "活动已结束，可以查看提交过的问卷问题及答案"),
    ACTIVITY_END_NOT_VIEW_ANSWER(200207, "活动已结束，无查看问卷链接"),

    NOT_ACQUIRE_PRIZE(300100, "该奖品无法被领取"),
    ALREADY_ACQUIRE_PRIZE(300101, "该奖品已被领取"),
    CREATE_ORDER_FAIL(300102, "创建订单失败"),


    ACTIVITY_USER_RECORD_NOT_NULL(400100, "参与记录不能为空"),
    ACTIVITY_USER_RECORD_DATA_SOURCE_TYPE_NOT_NULL(400101, "参与记录数据来源不能为空"),
    ACTIVITY_USER_RECORD_ACTIVITY_ID_NOT_NULL(400102, "参与记录活动id不能为空"),
    ACTIVITY_USER_RECORD_DATA_SOURCE_ID_NOT_NULL(400103, "参与记录数据来源id"),
    ACTIVITY_USER_RECORD_OPEN_ID_NOT_NULL(400104, "参与记录用户openId不能为空"),
    ACTIVITY_USER_RECORD_ACTIVITY_TITLE_NOT_NULL(400105, "参与记录用户活动名称不能为空"),
    ACTIVITY_USER_RECORD_JOIN_TIME_NOT_NULL(400106, "参与记录用户参与时间不能为空"),
    ACTIVITY_USER_RECORD_ACQUIRE_PRIZE_NOT_NULL(400107, "参与记录用户是否中奖不能为空"),

    CONSUMER_ID_NOT_NULL(500001,"用户id为空,请先登录"),
    CONSUMER_EXIST(500002,"用户不存在"),
    SALE_USER_INFO_EXIST(500003,"手机号已经与您绑定"),
    SALE_USER_INFO_NOT_EXIST(500004,"零售网用户手机号未绑定"),
    SALE_USER_INFO_MOBILE_NOT_EXIST(500005,"手机号未绑定"),
    NEW_OLD_MOBILE_NOT_EQUALS(500006,"新旧手机号不能相同"),
    HANDLER_IS_NULL(500007,"操作不支持"),

    SALE_CERTIFICATE_NOT_EXIST(500008,"专卖证没有被他人使用"),
    SALE_CERTIFICATE_EXIST(500009,"专卖证已经被他人使用"),
    SALE_CERTIFICATE_CREATE_BY_NOT_EQUALS(500010,"您已经绑定了这个专卖证"),

    NO_INTERVAL(500011, "未设置风控的发送间隔参数"),


    SUCCESS(20000, "成功"),
    ERROR(20001,"内部错误");






    ErrorCodeEnum(int code, String message) {
        this.code = code;
        this.message = message;
    }

    private int code;
    private String message;

    @Override
    public int errorCode() {
        return code;
    }

    @Override
    public String errorMessage() {
        return message;
    }
}

==> zhongyan-activity-service-api-1.0.24-linzhou-20220320.102540-1-sources.jar: cn/com/duiba/zhongyan/activity/service/api/enums/ErrorCodeEnum.java <==
package cn.com.duiba.zhongyan.activity.service.api.enums;

/**
 * @author LuHui
 * @description
 * @date 2021/11/25  16:30
 */
public enum ErrorCodeEnum implements BizError {

    FREQUENT_OPERATION(000001,"请求太频繁啦,请稍后再试"),

    PARAM_ERROR(100100, "参数错误"),
    ACTIVITY_NOT_EXIT(100101, "该活动不存在"),
    ACTIVITY_NOT_START(100102, "活动尚未开始"),
    ACTIVITY_ALREADY_END(100103, "活动已结束"),
    ANSWER_VERITY_AREA(100104, "仅限部门地区可参与"),
    ANSWER_VERIFY_USER(100105, "该活动仅限零售户参与"),
    ANSWER_VERITY(100106, "请先完成当前题目"),
    ANSWER_RECORD_NOT_EXIT(100107, "答题记录不存在"),
    ANSWER_NOT_COMMIT(100108, ""),

    NOT_OPERATION(200100, "无法操作"),
    NOT_ACQUIRE_LOCK(200101, "获取锁失败"),
    CAN_VIEW_ANSWER(200102,"查看答卷"),
    ANSWER_NOT_EMPTY(200103, "答案不能为空"),
    OPTION_NOT_EXIT(200104, "无此选项"),
    REQUIRED_MUST_FILL(200105,"该选项必填框必填"),
    ACTIVITY_END_VIEW_ANSWER(200106, "活动已结束，可以查看提交过的问卷问题及答案"),
    ACTIVITY_END_NOT_VIEW_ANSWER(200207, "活动已结束，无查看问卷链接"),

    NOT_ACQUIRE_PRIZE(300100, "该奖品无法被领取"),
    ALREADY_ACQUIRE_PRIZE(300101, "该奖品已被领取"),
    CREATE_ORDER_FAIL(300102, "创建订单失败"),


    ACTIVITY_USER_RECORD_NOT_NULL(400100, "参与记录不能为空"),
    ACTIVITY_USER_RECORD_DATA_SOURCE_TYPE_NOT_NULL(400101, "参与记录数据来源不能为空"),
    ACTIVITY_USER_RECORD_ACTIVITY_ID_NOT_NULL(400102, "参与记录活动id不能为空"),
    ACTIVITY_USER_RECORD_DATA_SOURCE_ID_NOT_NULL(400103, "参与记录数据来源id"),
    ACTIVITY_USER_RECORD_OPEN_ID_NOT_NULL(400104, "参与记录用户openId不能为空"),
    ACTIVITY_USER_RECORD_ACTIVITY_TITLE_NOT_NULL(400105, "参与记录用户活动名称不能为空"),
    ACTIVITY_USER_RECORD_JOIN_TIME_NOT_NULL(400106, "参与记录用户参与时间不能为空"),
    ACTIVITY_USER_RECORD_ACQUIRE_PRIZE_NOT_NULL(400107, "参与记录用户是否中奖不能为空"),

    CONSUMER_ID_NOT_NULL(500001,"用户id为空,请先登录"),
    CONSUMER_EXIST(500002,"用户不存在"),
    SALE_USER_INFO_EXIST(500003,"手机号已经与您绑定"),
    SALE_USER_INFO_NOT_EXIST(500004,"零售网用户手机号未绑定"),
    SALE_USER_INFO_MOBILE_NOT_EXIST(500005,"手机号未绑定"),
    NEW_OLD_MOBILE_NOT_EQUALS(500006,"新旧手机号不能相同"),
    HANDLER_IS_NULL(500007,"操作不支持"),

    SALE_CERTIFICATE_NOT_EXIST(500008,"专卖证没有被他人使用"),
    SALE_CERTIFICATE_EXIST(500009,"当前专卖号已经被他人使用,是否申诉"),
    SALE_CERTIFICATE_CREATE_BY_NOT_EQUALS(500010,"您已经绑定了这个专卖证"),

    NO_INTERVAL(500011, "未设置风控的发送间隔参数"),
    AUDIT_SHEET_ID_SALE_CERTIFICATE_EXIST(500012,"您已经提交了该专卖证号的审核"),
    SALE_CERTIFICATE_NO_ERROR(500013,"1. 专卖证号格式错误"),
    AUDIT_SHEET_NOT_EXIST(500014,"审核单不存在"),
    AUDIT_SHEET_IS_UPDATE(500015,"审核单请刷新页面后在操作"),
    SALE_USER_INFO_MOBILE_EXIST(500016,"手机号已经被绑定"),

    SEND_VERIFICATION_MAX(500017, "发送间隔达到上限"),
    OTHER_PEOPLE_USED(500018, "号码已被占用"),



    SUCCESS(20000, "成功"),
    ERROR(20001,"内部错误");






    ErrorCodeEnum(int code, String message) {
        this.code = code;
        this.message = message;
    }

    private int code;
    private String message;

    @Override
    public int errorCode() {
        return code;
    }

    @Override
    public String errorMessage() {
        return message;
    }
}
